@@ -1,4 +1,4 @@
-# Copyright (C) 2003-2024 Free Software Foundation, Inc.
+# Copyright (C) 2003-2012 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -11,16 +11,13 @@
 # GNU General Public License for more details.
 
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <https://www.gnu.org/licenses/>.
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 package Automake::Variable;
 
 use 5.006;
 use strict;
-use warnings FATAL => 'all';
-
 use Carp;
-use Exporter;
 
 use Automake::Channels;
 use Automake::ChannelDefs;
@@ -32,18 +29,20 @@ use Automake::DisjConditions;
 use Automake::General 'uniq';
 use Automake::Wrap 'makefile_wrap';
 
-our @ISA = qw (Automake::Item Exporter);
-our @EXPORT = qw (err_var msg_var msg_cond_var reject_var
-		  var rvar vardef rvardef
-		  variables
-		  scan_variable_expansions check_variable_expansions
-		  variable_delete
-		  variables_dump
-		  set_seen
-		  require_variables
-		  variable_value
-		  output_variables
-		  transform_variable_recursively);
+require Exporter;
+use vars '@ISA', '@EXPORT', '@EXPORT_OK';
+@ISA = qw/Automake::Item Exporter/;
+@EXPORT = qw (err_var msg_var msg_cond_var reject_var
+	      var rvar vardef rvardef
+	      variables
+	      scan_variable_expansions check_variable_expansions
+	      variable_delete
+	      variables_dump
+	      set_seen
+	      require_variables
+	      variable_value
+	      output_variables
+	      transform_variable_recursively);
 
 =head1 NAME
 
@@ -132,9 +131,7 @@ non-object).
 =cut
 
 my $_VARIABLE_CHARACTERS = '[.A-Za-z0-9_@]+';
-my $_VARIABLE_PATTERN_EXTRA_POSIX = '[*?<%][DF]?';
-my $_VARIABLE_PATTERN = '^(' . $_VARIABLE_CHARACTERS
-                             . '|' . $_VARIABLE_PATTERN_EXTRA_POSIX . ")\$";
+my $_VARIABLE_PATTERN = '^' . $_VARIABLE_CHARACTERS . "\$";
 my $_VARIABLE_RECURSIVE_PATTERN =
     '^([.A-Za-z0-9_@]|\$[({]' . $_VARIABLE_CHARACTERS . '[})]?)+' . "\$";
 
@@ -201,8 +198,7 @@ my $configure_ac;
 
 # Variables that can be overridden without complaint from -Woverride
 my %_silent_variable_override =
-  (AM_DISTCHECK_DVI_TARGET => 1,
-   AM_MAKEINFOHTMLFLAGS => 1,
+  (AM_MAKEINFOHTMLFLAGS => 1,
    AR => 1,
    ARFLAGS => 1,
    DEJATOOL => 1,
@@ -302,7 +298,7 @@ is the value being appended to  C<$varname>.
 
 =cut
 
-our %_hooks;
+use vars '%_hooks';
 sub hook ($$)
 {
   my ($var, $fun) = @_;
@@ -317,25 +313,25 @@ the L<Automake::Variable> instances that ends with C<_$suffix>.
 
 =cut
 
-our (%_variable_dict, %_primary_dict);
+use vars '%_variable_dict', '%_primary_dict';
 sub variables (;$)
 {
   my ($suffix) = @_;
-  my @vars = ();
   if ($suffix)
     {
       if (exists $_primary_dict{$suffix})
 	{
-	  @vars = values %{$_primary_dict{$suffix}};
+	  return values %{$_primary_dict{$suffix}};
+	}
+      else
+	{
+	  return ();
 	}
     }
   else
     {
-      @vars = values %_variable_dict;
+      return values %_variable_dict;
     }
-  # The behavior of the 'sort' built-in is undefined in scalar
-  # context, hence we need an ad-hoc handling for such context.
-  return wantarray ? sort { $a->name cmp $b->name } @vars : scalar @vars;
 }
 
 =item C<Automake::Variable::reset>
@@ -748,10 +744,9 @@ sub scan_variable_expansions ($)
   $text =~ s/#.*$//;
 
   # Record each use of ${stuff} or $(stuff) that does not follow a $.
-  while ($text =~ m{\$(?:\{([^\}]*)\}|\(([^\)]*)\)|(\$))}g)
+  while ($text =~ /(?<!\$)\$(?:\{([^\}]*)\}|\(([^\)]*)\))/g)
     {
-      my $var = $1 || $2 || $3;
-      next if $var eq '$';
+      my $var = $1 || $2;
       # The occurrence may look like $(string1[:subst1=[subst2]]) but
       # we want only 'string1'.
       $var =~ s/:[^:=]*=[^=]*$//;
@@ -860,9 +855,6 @@ sub define ($$$$$$$$)
   msg ('portability', $where, "':='-style assignments are not portable")
     if $type eq ':';
 
-  msg ('portability', $where, "escaping \\# comment markers is not portable")
-    if index ($value, '\#') != -1;
-
   check_variable_expansions ($value, $where);
 
   # If there's a comment, make sure it is \n-terminated.
@@ -1088,7 +1080,7 @@ For debugging.
 sub variables_dump ()
 {
   my $text = "all variables:\n{\n";
-  foreach my $var (variables())
+  foreach my $var (sort { $a->name cmp $b->name } variables)
     {
       $text .= $var->dump;
     }
@@ -1682,3 +1674,20 @@ L<Automake::DisjConditions>, L<Automake::Location>.
 =cut
 
 1;
+
+### Setup "GNU" style for perl-mode and cperl-mode.
+## Local Variables:
+## perl-indent-level: 2
+## perl-continued-statement-offset: 2
+## perl-continued-brace-offset: 0
+## perl-brace-offset: 0
+## perl-brace-imaginary-offset: 0
+## perl-label-offset: -2
+## cperl-indent-level: 2
+## cperl-brace-offset: 0
+## cperl-continued-brace-offset: 0
+## cperl-label-offset: -2
+## cperl-extra-newline-before-brace: t
+## cperl-merge-trailing-else: nil
+## cperl-continued-statement-offset: 2
+## End:
