@@ -18,7 +18,7 @@
 # placed in a subdirectory.
 # Related to automake bug#7819.
 
-. ./defs || exit 1
+. test-init.sh
 
 cat >> configure.ac <<END
 AC_CONFIG_FILES([sub/Makefile])
