@@ -19,7 +19,7 @@
 # Related to automake bug#7819.
 
 required=makeinfo
-. ./defs || exit 1
+. test-init.sh
 
 cat >> configure.ac << END
 AC_OUTPUT
