@@ -24,7 +24,7 @@
 #
 # Keep this test in sync with sister test 'autodist.sh'.
 
-. ./defs || exit 1
+. test-init.sh
 
 cat >> configure.ac <<'END'
 AC_CONFIG_FILES([sub/Makefile])
