@@ -16,7 +16,7 @@
 
 # Yet another canonicalization test.
 
-. ./defs || exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AC_PROG_CC
