@@ -16,7 +16,7 @@
 
 # Check for use of = and += in different conditions.
 
-. ./defs || exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AM_CONDITIONAL([COND1], [true])
