@@ -22,7 +22,7 @@
 # aren't left around.  Report from Jim Meyering.
 
 required=cc
-. ./defs || Exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AC_PROG_CC
@@ -62,10 +62,10 @@ grep '^maude\.static$(EXEEXT):' Makefile.in
 grep '^maude3$(EXEEXT):' Makefile.in
 grep '^mt$(EXEEXT):' Makefile.in
 grep '^rmt$(EXEEXT):' Makefile.in
-test `grep '^bin_PROGRAMS =' Makefile.in | wc -l` = 1
+test $(grep -c '^bin_PROGRAMS =' Makefile.in) -eq 1
 
 # Make sure $(EXEEXT) gets stripped before canonicalization.
-grep 'maude3__EXEEXT__OBJECTS' Makefile.in && Exit 1
+grep 'maude3__EXEEXT__OBJECTS' Makefile.in && exit 1
 
 ./configure
 
@@ -86,3 +86,5 @@ grep '1BEG: maude.foo :END1' stdout
 grep '2BEG: maude.static.foo :END2' stdout
 grep '3BEG: maude3.foo :END3' stdout
 grep '4BEG: :END4' stdout
+
+:
