@@ -16,9 +16,9 @@
 
 # If $(foodir) is the empty string, then nothing should be installed there.
 # This test ensures this also if $(foo_PRIMARY) is nonempty, see
-# instdir.test.
+# 'instdir.sh'.
 
-. ./defs || exit 1
+. test-init.sh
 
 cat >>configure.ac <<'END'
 AC_SUBST([foodir], ['${datadir}'/foo])
