@@ -20,7 +20,7 @@
 # This is the libtool sister test of 'instfail.sh'.
 
 required='cc libtool libtoolize'
-. ./defs || exit 1
+. test-init.sh
 
 cat >>configure.ac <<END
 AM_PROG_AR
