@@ -20,7 +20,7 @@
 # xxx_LDFLAGS.
 
 required='cc libtoolize'
-. ./defs || exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AC_PROG_CC
