@@ -14,37 +14,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-# Check that the AM_PROG_MKDIR_P macro is deprecated; it will be
-# be removed in the next major Automake release.  But also check
-# that it still works as expected in the current release series.
+# Check that the AM_PROG_MKDIR_P macro is deprecated.  It will be
+# be removed in the next major Automake release.
 
-. ./defs || exit 1
+. test-init.sh
 
-cat >> configure.ac << 'END'
-AM_PROG_MKDIR_P
-AC_CONFIG_FILES([sub/Makefile])
-AC_OUTPUT
-END
-
-cat > Makefile.am << 'END'
-SUBDIRS = sub
-all-local:
-	$(mkdir_p) . dir1/a
-	@mkdir_p@ . dir2/b
-check-local: all
-	test -d dir1/a
-	test -d dir2/b
-	test -d dir3/c
-	test -d dir3/d
-END
-
-mkdir sub
-cat > sub/Makefile.am << 'END'
-# '$(mkdir_p)' should continue to work even in subdir makefiles.
-all-local:
-	$(mkdir_p) .. ../dir3/c
-	@mkdir_p@ .. ../dir3/d
-END
+echo AM_PROG_MKDIR_P >> configure.ac
+: > Makefile.am
 
 grep_err ()
 {
@@ -62,15 +38,11 @@ grep_err
 
 $AUTOCONF -Werror -Wno-obsolete
 
-AUTOMAKE_fails
-grep_err
+#AUTOMAKE_fails
+#grep_err
 AUTOMAKE_fails --verbose -Wnone -Wobsolete
 grep_err
 
 $AUTOMAKE -Wno-obsolete
 
-./configure
-$MAKE check-local
-$MAKE distcheck
-
 :
