@@ -18,7 +18,7 @@
 # (or even be) $(EXTRA_PROGRAMS).
 
 required='cc native'
-. ./defs || Exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AC_PROG_CC
@@ -121,10 +121,10 @@ cat stdout
 cat stderr >&2
 ls -l
 if using_gmake; then
-  test $st -gt 0 || Exit 1
+  test $st -gt 0 || exit 1
 else
   # Don't trust exit status of "make -k" for non-GNU make.
-  $MAKE check && Exit 1
+  $MAKE check && exit 1
   : For shells with busted 'set -e'.
 fi
 
@@ -134,8 +134,8 @@ grep foofoofoo foo.log
 grep barbarbar bar.log
 grep yepyepyep baz.log
 # Files that shouldn't have been created.
-test ! -f none.log
-test ! -f test-suite.log
+test ! -e none.log
+test ! -e test-suite.log
 # Expected testsuite progress output.
 grep '^PASS: baz\.test$' stdout
 # Don't anchor the end of the next two patterns, to allow for non-empty
@@ -162,7 +162,7 @@ st=0
 RECHECK_LOGS= $MAKE -e check >stdout || st=$?
 cat stdout
 ls -l
-test $st -eq 0 || Exit 1
+test $st -eq 0 || exit 1
 
 # For debugging.
 stat stamp foo.log bar.log baz.log || :
@@ -173,7 +173,7 @@ is_newest stamp foo.log bar.log baz.log
 test -f none.log
 test -f test-suite.log
 # Tests that shouldn't have been re-run.
-$EGREP '(foo|bar)\.bin|baz\.test$' stdout && Exit 1
+$EGREP '(foo|bar)\.bin|baz\.test$' stdout && exit 1
 # Tests that should have been run.  Again, we don't anchor the end
 # of the next pattern, to allow for non-empty $(EXEEXT).
 grep '^PASS: none\.bin' stdout
