@@ -18,7 +18,7 @@
 #  - If $(TEST_SUITE_LOG) is in $(TEST_LOGS), we get a diagnosed
 #    error, not a make hang or a system freeze.
 
-. ./defs || Exit 1
+. test-init.sh
 
 # We don't want localized error messages from make, since we'll have
 # to grep them.  See automake bug#11452.
@@ -102,9 +102,9 @@ do_check ()
   log=$1; shift
   env "$@" $MAKE -e check >output 2>&1 || st=$?
   cat output
-  $FGREP '::OOPS::' output && Exit 1 # Possible infinite recursion.
+  $FGREP '::OOPS::' output && exit 1 # Possible infinite recursion.
   # Check that at least we don't create a botched global log file.
-  test ! -f "$log"
+  test ! -e "$log"
   if using_gmake; then
     grep "[Cc]ircular.*dependency" output | $FGREP "$log"
     test $st -gt 0
@@ -128,7 +128,7 @@ do_check ()
       err_seen=yes
       break
     done
-    test $err_seen = yes || Exit 1
+    test $err_seen = yes || exit 1
   fi
 }
 
