@@ -16,7 +16,7 @@
 
 # Test to make sure backslash-newline is treated as whitespace.
 
-. ./defs || Exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AC_PROG_CC
@@ -32,5 +32,5 @@ END
 $ACLOCAL
 $AUTOMAKE
 
-$FGREP zar.cdoz Makefile.in && Exit 1
-Exit 0
+$FGREP zar.cdoz Makefile.in && exit 1
+exit 0
