@@ -18,7 +18,7 @@
 # and renamed.
 
 required=cc
-. ./defs || exit 1
+. test-init.sh
 
 cat >configure.ac <<END
 AC_INIT([$me], [1.0])
