@@ -26,7 +26,7 @@
 # See also "semantic" sister test 'subobj11a.sh', and related test
 # 'subobj11c.sh'.
 
-. ./defs || exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AC_PROG_CC
